package com.gxlu.ps.netcruise.md.sender;

import com.gxlu.ps.netcruise.md.Configer;
import com.gxlu.ps.netcruise.md.GlobalInstance;
import com.gxlu.ps.netcruise.md.util.Alarm;
import java.io.IOException;
import java.io.OutputStream;
import java.net.Socket;
import java.util.LinkedList;
import org.apache.log4j.Logger;

/* loaded from: com_gxlu_ps_netcruise_md_sender.jar:com/gxlu/ps/netcruise/md/sender/TestSender.class */
public class TestSender extends Thread {
    protected static final int DISCONNECT = 0;
    protected static final int CONNECTED = 1;
    protected Socket socket;
    protected int maxInterval;
    protected String NCAddr;
    protected int NCPort;
    protected int queueSize;
    private static TestSender instance = null;
    private Logger logger;
    protected OutputStream os = null;
    protected int bufPt = DISCONNECT;
    protected int interval = DISCONNECT;
    protected boolean powerOn = true;
    protected int state = DISCONNECT;
    protected LinkedList senderQueue = new LinkedList();

    private TestSender(String addr, int port, int maxIntvl, int queueSize) {
        this.logger = null;
        this.NCAddr = addr;
        this.NCPort = port;
        this.maxInterval = maxIntvl * 60;
        this.queueSize = queueSize;
        this.logger = GlobalInstance.getInstance().getLogger();
        this.logger.trace("TestSender: init finished.");
    }

    public static synchronized TestSender getInstance() {
        if (instance == null) {
            try {
                Configer cf = GlobalInstance.getInstance().getConfiger();
                instance = new TestSender(cf.getTestNetcoolAddr(), cf.getTestNetcoolPort(), cf.getMaxRetryInterval(), cf.getTestSendCacheSize());
            } catch (Exception e) {
                return (TestSender) null;
            }
        }
        return instance;
    }

    protected boolean connectNC() {
        try {
            this.socket = new Socket(this.NCAddr, this.NCPort);
            this.os = this.socket.getOutputStream();
            this.logger.info("TestSender: Netcool connected.");
            return true;
        } catch (Exception e) {
            this.logger.error("TestSender: connect Netcool failed.");
            return false;
        }
    }

    protected void connectRule() {
        if (this.powerOn) {
            while (!connectNC()) {
                if (this.interval == 0) {
                    this.interval = CONNECTED;
                } else {
                    int i = this.interval << CONNECTED;
                    this.interval = i;
                    this.interval = i < this.maxInterval ? this.interval : this.maxInterval;
                    try {
                        Thread.sleep(this.interval * 1000);
                    } catch (InterruptedException e) {
                    }
                    if (!this.powerOn) {
                        this.state = DISCONNECT;
                        return;
                    }
                }
            }
            this.interval = DISCONNECT;
            this.state = CONNECTED;
            return;
        }
        this.interval = CONNECTED;
        this.state = DISCONNECT;
    }

    public void shutdown(boolean off) {
        this.powerOn = !off;
    }

    protected boolean sendRule(Alarm alm) {
        String str = alm.getContent();
        byte[] buf = str.getBytes();
        if (this.socket.isOutputShutdown()) {
            return false;
        }
        try {
            this.os.write(buf);
            this.os.flush();
            this.logger.debug("Sender.sendRule:has sended ".concat(String.valueOf(String.valueOf(str))));
            return true;
        } catch (IOException e) {
            this.logger.error("TestSender.sendRule:failed in send ".concat(String.valueOf(String.valueOf(str))));
            return false;
        }
    }

    @Override // java.lang.Thread, java.lang.Runnable
    public void run() {
        while (true) {
            if (!this.powerOn) {
                break;
            }
            if (this.state == 0) {
                connectRule();
            }
            if (!this.powerOn) {
                break;
            }
            LinkedList var2 = this.senderQueue;
            synchronized (var2) {
                if (this.senderQueue.size() == 0) {
                    try {
                        this.senderQueue.wait();
                    } catch (InterruptedException e) {
                    }
                    if (!this.powerOn) {
                        break;
                    }
                } else {
                    Alarm alm = (Alarm) this.senderQueue.removeFirst();
                    if (!sendRule(alm)) {
                        this.state = DISCONNECT;
                    }
                }
            }
            break;
        }
        this.senderQueue.clear();
        if (this.socket != null) {
            try {
                this.socket.close();
            } catch (IOException e2) {
            }
            this.socket = null;
            this.state = DISCONNECT;
        }
        this.logger.info("TestSender: Sender alarm thread stopped.");
    }

    public void putAlarm(Alarm alm) {
        synchronized (this.senderQueue) {
            if (this.queueSize > this.senderQueue.size()) {
                this.senderQueue.add(alm);
            }
            this.senderQueue.notifyAll();
        }
    }
}
